@@ -247,62 +247,60 @@ add_layer <- function (params, layer, fn = NULL) {
   
   
   
-  
-  
   result <- list()
   
   
   
   attr(result, 'function') <- switch(
     EXPR = layer,
-    'ggplot'       = ggplot,
-    'arrow'        = geom_segment,
-    'bar'          = geom_bar,
-    'box'          = geom_boxplot,
-    'brackets'     = geom_segment,
-    'color'        = scale_color_manual,
-    'confidence'   = geom_ribbon,
-    'crossbar'     = geom_crossbar,
-    'density'      = geom_hdr,
-    'dot'          = geom_beeswarm,
-    'errorbar'     = geom_errorbar,
-    'ellipse'      = stat_ellipse,
-    'facet'        = if (facetDims == 2) facet_grid else facet_wrap,
-    'fill'         = if (patterned) scale_fill_pattern else scale_fill_manual,
-    'flip'         = coord_flip,
-    # 'free_y'     = facetted_pos_scales,
-    'hline'        = geom_hline,
-    'label'        = geom_label,
-    'labs'         = labs,
-    'linerange'    = geom_linerange,
-    'mean'         = geom_point,
-    'name'         = geom_text,
-    'pointrange'   = geom_pointrange,
-    'point'        = geom_point,
-    'rect'         = geom_rect,
-    'residual'     = geom_segment,
-    'shape'        = scale_shape_manual,
-    'smooth'       = stat_smooth,
-    'spider'       = geom_segment,
-    'stack'        = geom_col,
-    'stats_bg'     = geom_rect,
-    'stats_ggtext' = geom_textbox,
-    'stats_label'  = geom_label,
-    'stats_text'   = geom_text,
-    'stats_vline'  = geom_vline,
-    'strip'        = geom_quasirandom,
-    'stripe'       = geom_rect,
-    'table'        = annotation_custom,
-    'taxon'        = geom_label_repel,
-    'theme'        = theme,
-    'theme_bw'     = theme_bw,
-    'topo'         = geom_hdr_lines,
-    'trend'        = geom_line,
-    'violin'       = geom_violin,
-    'vline'        = geom_vline,
-    'xaxis'        = if (xmode == "factor") scale_x_discrete else scale_x_continuous,
-    'yaxis'        = scale_y_continuous,
-    if (is.null(fn)) get(layer) else get(fn) )
+    'ggplot'       = P('ggplot2::ggplot'),
+    'arrow'        = P('ggplot2::geom_segment'),
+    'bar'          = P('ggplot2::geom_bar'),
+    'box'          = P('ggplot2::geom_boxplot'),
+    'brackets'     = P('ggplot2::geom_segment'),
+    'color'        = P('ggplot2::scale_color_manual'),
+    'confidence'   = P('ggplot2::geom_ribbon'),
+    'crossbar'     = P('ggplot2::geom_crossbar'),
+    'density'      = P('ggdensity::geom_hdr'),
+    'dot'          = P('ggbeeswarm::geom_beeswarm'),
+    'errorbar'     = P('ggplot2::geom_errorbar'),
+    'ellipse'      = P('ggplot2::stat_ellipse'),
+    'facet'        = if (facetDims == 2) P('ggplot2::facet_grid') else P('ggplot2::facet_wrap'),
+    'fill'         = if (patterned) P('fillpattern::scale_fill_pattern') else P('ggplot2::scale_fill_manual'),
+    'flip'         = P('ggplot2::coord_flip'),
+    # 'free_y'     = P('ggplot2::facetted_pos_scales'),
+    'hline'        = P('ggplot2::geom_hline'),
+    'label'        = P('ggplot2::geom_label'),
+    'labs'         = P('ggplot2::labs'),
+    'linerange'    = P('ggplot2::geom_linerange'),
+    'mean'         = P('ggplot2::geom_point'),
+    'name'         = P('ggplot2::geom_text'),
+    'pointrange'   = P('ggplot2::geom_pointrange'),
+    'point'        = P('ggplot2::geom_point'),
+    'rect'         = P('ggplot2::geom_rect'),
+    'residual'     = P('ggplot2::geom_segment'),
+    'shape'        = P('ggplot2::scale_shape_manual'),
+    'smooth'       = P('ggplot2::stat_smooth'),
+    'spider'       = P('ggplot2::geom_segment'),
+    'stack'        = P('ggplot2::geom_col'),
+    'stats_bg'     = P('ggplot2::geom_rect'),
+    'stats_ggtext' = P('ggtext::geom_textbox'),
+    'stats_label'  = P('ggplot2::geom_label'),
+    'stats_text'   = P('ggplot2::geom_text'),
+    'stats_vline'  = P('ggplot2::geom_vline'),
+    'strip'        = P('ggbeeswarm::geom_quasirandom'),
+    'stripe'       = P('ggplot2::geom_rect'),
+    'table'        = P('ggplot2::annotation_custom'),
+    'taxon'        = P('ggrepel::geom_label_repel'),
+    'theme'        = P('ggplot2::theme'),
+    'theme_bw'     = P('ggplot2::theme_bw'),
+    'topo'         = P('ggdensity::geom_hdr_lines'),
+    'trend'        = P('ggplot2::geom_line'),
+    'violin'       = P('ggplot2::geom_violin'),
+    'vline'        = P('ggplot2::geom_vline'),
+    'xaxis'        = if (xmode == "factor") P('ggplot2::scale_x_discrete') else P('ggplot2::scale_x_continuous'),
+    'yaxis'        = P('ggplot2::scale_y_continuous'),
+    if (is.null(fn)) P(paste0('ggplot2::', layer)) else get(fn) )
   
   
   attr(result, 'src') <- switch(
